#!/bin/bash

ID=`date +%s.%N`
FROM=""
FROMNAME=""
TO=""
BODY=""
URGENT=0
RING=1
CONFIRMATION=1
PRIORITY=1

MSGTYPE=""

usage() {
    echo "Usage: astfilewriter.sh [-i id] -m messagetype [-f from] [-n fromname] -t to [-u urgent] [-r ring] [-c confirmationtype] [-p priority] -s text"
    echo "-i: id of message or alarm"
    echo "-m: message type can be either alarm or sms"
    echo "-f: from number (only for sms)"
    echo "-n: from name (only for sms)"
    echo "-t: to number"
    echo "-u: urgent can be 0 or 1 (only for sms)"
    echo "-r: ring count, 0 to 9 (0 = unlimited). default 1. (only for alarm)"
    echo "-c: confirmation service, can be 1 or 2. default 1. (only for alarm)"
    echo "-p: priority, 1 to 9. default 1. (only for alarm)"
    echo "-s: Text to send"
}

checkopts() {
    if [ -z "$TO" ]
    then
        echo "Missing -t option"
        usage
        exit 1
    fi
    if [ -z "$BODY" ]
    then
        echo "Missing -s option"
        usage
        exit 1
    fi
    if [ "$MSGTYPE" = "sms" ]
    then
        if [ -z "$FROM" ]
        then
            echo "Missing -f option"
            usage
            exit 1
        fi
        if [ -z "$FROMNAME" ]
        then
            FROMNAME=$FROM
        fi
    fi
}

dosms() {
    echo "{ \"id\": \"$ID\", \"from\": \"$FROM\", \"fromname\": \"$FROMNAME\", \"to\": \"$TO\", \"body\": \"$BODY\", \"urgent\": \"$URGENT\" }" > /var/spool/ipcas/sms/${ID}
}

doalarm() {
    echo "{ \"id\": \"$ID\", \"to\": \"$TO\", \"body\": \"$BODY\", \"ring\": \"$RING\", \"confirmation\": \"$CONFIRMATION\", \"priority\": \"$PRIORITY\" }" > /var/spool/ipcas/alarm/${ID}
}

while getopts "i:m:f:n:t:u:r:c:p:s:" o
do
    case "${o}" in
        i)
            ID=${OPTARG}
            ;;
        m)
            MSGTYPE=${OPTARG}
            ;;
        f)
            FROM=${OPTARG}
            ;;
        n)
            FROMNAME=${OPTARG}
            ;;
        t)
            TO=${OPTARG}
            ;;
        u)
            URGENT=${OPTARG}
            ;;
        r)
            RING=${OPTARG}
            ;;
        c)
            CONFIRMATION=${OPTARG}
            ;;
        p)
            PRIORITU=${OPTARG}
            ;;
        s)
            BODY=${OPTARG}
            ;;
        *)
            usage
            ;;
    esac
done

case "$MSGTYPE" in
    sms)
        checkopts
        dosms
        ;;
    alarm)
        checkopts
        doalarm
        ;;
    *)
        echo "Unknown message type ${OPTARG}"
        usage
        ;;
esac

exit 0